@@ -7,7 +7,6 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-
 namespace SebastianBergmann\Comparator;
 
 /**
@@ -46,11 +45,11 @@ class NumericComparator extends ScalarComparator
     public function assertEquals($expected, $actual, $delta = 0.0, $canonicalize = false, $ignoreCase = false)
     {
         if (\is_infinite($actual) && \is_infinite($expected)) {
-            return;
+            return; // @codeCoverageIgnore
         }
 
         if ((\is_infinite($actual) xor \is_infinite($expected)) ||
-            (\is_nan($actual) or \is_nan($expected)) ||
+            (\is_nan($actual) || \is_nan($expected)) ||
             \abs($actual - $expected) > $delta) {
             throw new ComparisonFailure(
                 $expected,
